@@ -136,6 +136,7 @@ class MemoryUnitConsts():
     TYPE_DDR2_FB_DIMM = "DDR2 FB-DIMM"
     TYPE_DDR3 = "DDR3"
     TYPE_DDR4 = "DDR4"
+    TYPE_DDR5 = "DDR5"
     TYPE_DRAM = "DRAM"
     TYPE_EDRAM = "EDRAM"
     TYPE_EEPROM = "EEPROM"
@@ -143,6 +144,7 @@ class MemoryUnitConsts():
     TYPE_FBD2 = "FBD2"
     TYPE_FEPROM = "FEPROM"
     TYPE_FLASH = "FLASH"
+    TYPE_LOGICAL_NON_VOLATILE_DEVICE = "Logical non-volatile device"
     TYPE_OTHER = "Other"
     TYPE_RAM = "RAM"
     TYPE_RDRAM = "RDRAM"
@@ -172,9 +174,9 @@ class MemoryUnit(ManagedObject):
     """This is MemoryUnit class."""
 
     consts = MemoryUnitConsts()
-    naming_props = set([u'id'])
+    naming_props = set(['id'])
 
-    mo_meta = MoMeta("MemoryUnit", "memoryUnit", "mem-[id]", VersionMeta.Version111a, "InputOutput", 0x3f, [], ["read-only"], [u'memoryArray'], [u'faultInst', u'memoryErrorStats', u'memoryUnitEnvStats'], ["Get"])
+    mo_meta = MoMeta("MemoryUnit", "memoryUnit", "mem-[id]", VersionMeta.Version111a, "InputOutput", 0x3f, [], ["read-only"], ['memoryArray'], ['faultInst', 'memoryErrorStats', 'memoryUnitEnvStats'], ["Get"])
 
     prop_meta = {
         "admin_state": MoPropertyMeta("admin_state", "adminState", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["policy", "reset-errors"], []), 
@@ -204,7 +206,7 @@ class MemoryUnit(ManagedObject):
         "speed": MoPropertyMeta("speed", "speed", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]), 
         "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
         "thermal": MoPropertyMeta("thermal", "thermal", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []), 
-        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["3DRAM", "CDRAM", "DDR", "DDR2", "DDR2 FB-DIMM", "DDR3", "DDR4", "DRAM", "EDRAM", "EEPROM", "EPROM", "FBD2", "FEPROM", "FLASH", "Other", "RAM", "RDRAM", "ROM", "SDRAM", "SGRAM", "SRAM", "Unknown", "VRAM", "undiscovered"], []), 
+        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["3DRAM", "CDRAM", "DDR", "DDR2", "DDR2 FB-DIMM", "DDR3", "DDR4", "DDR5", "DRAM", "EDRAM", "EEPROM", "EPROM", "FBD2", "FEPROM", "FLASH", "Logical non-volatile device", "Other", "RAM", "RDRAM", "ROM", "SDRAM", "SGRAM", "SRAM", "Unknown", "VRAM", "undiscovered"], []), 
         "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
         "visibility": MoPropertyMeta("visibility", "visibility", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["no", "unknown", "yes"], []), 
         "voltage": MoPropertyMeta("voltage", "voltage", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["lower-critical", "lower-non-critical", "lower-non-recoverable", "not-supported", "ok", "unknown", "upper-critical", "upper-non-critical", "upper-non-recoverable"], []), 
