@@ -42,6 +42,7 @@ class StorageScsiLunConsts():
     DEPLOY_ACTION_RESTORE = "restore"
     DEPLOY_ACTION_SET_OFFLINE = "set-offline"
     DEPLOY_ACTION_SET_ONLINE = "set-online"
+    ID_UNSPECIFIED = "unspecified"
     LUN_MAP_TYPE_NON_SHARED = "non-shared"
     LUN_MAP_TYPE_SHARED = "shared"
     LUN_MAP_TYPE_UNASSIGNED = "unassigned"
@@ -129,9 +130,9 @@ class StorageScsiLun(ManagedObject):
     """This is StorageScsiLun class."""
 
     consts = StorageScsiLunConsts()
-    naming_props = set([u'name'])
+    naming_props = set(['name'])
 
-    mo_meta = MoMeta("StorageScsiLun", "storageScsiLun", "lun-[name]", VersionMeta.Version131a, "InputOutput", 0x1ff, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], [u'storagePartition'], [u'faultInst', u'storageInitiatorRef', u'storageReplicationCtx', u'storageScsiDeviceDescriptor', u'storageScsiLunCtx', u'storageScsiLunRef', u'storageSnapshotCtx'], [None])
+    mo_meta = MoMeta("StorageScsiLun", "storageScsiLun", "lun-[name]", VersionMeta.Version131a, "InputOutput", 0x1ff, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], ['storagePartition'], ['faultInst', 'storageInitiatorRef', 'storageReplicationCtx', 'storageScsiDeviceDescriptor', 'storageScsiLunCtx', 'storageScsiLunRef', 'storageSnapshotCtx'], [None])
 
     prop_meta = {
         "actual_size": MoPropertyMeta("actual_size", "actualSize", "ulong", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
@@ -147,7 +148,7 @@ class StorageScsiLun(ManagedObject):
         "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
         "device_id": MoPropertyMeta("device_id", "deviceId", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
         "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
-        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, [], []), 
+        "id": MoPropertyMeta("id", "id", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["unspecified"], ["0-4294967295"]), 
         "last_snapshot_id": MoPropertyMeta("last_snapshot_id", "lastSnapshotId", "uint", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
         "locale": MoPropertyMeta("locale", "locale", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
         "lun_map_type": MoPropertyMeta("lun_map_type", "lunMapType", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["non-shared", "shared", "unassigned"], []), 
