@@ -42,41 +42,119 @@ class UcscVersion(object):
             return None
 
         self.__version = version
+        self.__major = None
+        self.__minor = None
+        self.__mr = None
+        self.__patch = None
+        self.__spin = None
+        self.__build = None
 
-        match_pattern = re.compile("^(?P<major>[1-9][0-9]{0,2})\."
-                                   "(?P<minor>(([0-9])|([1-9][0-9]?)))\("
-                                   "(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\."
-                                   "(?P<patch>(([0-9])|([1-9][0-9]{0,4})))\)$")
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]?)))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\."
+                                   r"(?P<patch>(([0-9])|([1-9][0-9]{0,4})))\)$")
         match_obj = re.match(match_pattern, version)
-        if match_obj:
-            self.__major = match_obj.group("major")
-            self.__minor = match_obj.group("minor")
-            self.__mr = match_obj.group("mr")
-            self.__patch = match_obj.group("patch")
+        if self._set_versions(match_obj):
             return
 
-        match_pattern = re.compile("^(?P<major>[1-9][0-9]{0,2})\."
-                                   "(?P<minor>(([0-9])|([1-9][0-9]?)))\("
-                                   "(?P<mr>(([0-9])|([1-9][0-9]{0,2})))"
-                                   "(?P<patch>[a-z])\)$")
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]?)))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))"
+                                   r"(?P<patch>[a-z])\)$")
         match_obj = re.match(match_pattern, version)
-        if match_obj:
-            self.__major = match_obj.group("major")
-            self.__minor = match_obj.group("minor")
-            self.__mr = match_obj.group("mr")
-            self.__patch = match_obj.group("patch")
+        if self._set_versions(match_obj):
             return
 
-        match_pattern = re.compile("^(?P<major>[1-9][0-9]{0,2})\."
-                                   "(?P<minor>(([0-9])|([1-9][0-9]?)))\("
-                                   "(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\)$")
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]?)))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\)$")
         match_obj = re.match(match_pattern, version)
-        if match_obj:
-            self.__major = match_obj.group("major")
-            self.__minor = match_obj.group("minor")
-            self.__mr = match_obj.group("mr")
+        if self._set_versions(match_obj):
             return
 
+        # handle spin builds "2.0(13aS1))"
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]{0,1})))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))"
+                                   r"(?P<patch>[a-z])"
+                                   r"(?P<spin>S[1-9][0-9]{0,2})\)$")
+        match_obj = re.match(match_pattern, version)
+        if self._set_versions(match_obj):
+            return
+
+        # handle spin builds "3.0(1S10))"
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]{0,1})))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))"
+                                   r"(?P<spin>S[1-9][0-9]{0,2})\)$")
+        match_obj = re.match(match_pattern, version)
+        if self._set_versions(match_obj):
+            return
+
+        # handle de special builds "66.77(67.1582251418)"
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]{0,2})))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\."
+                                   r"(?P<patch>(([0-9])|([1-9][0-9]{0,})))\)$")
+        match_obj = re.match(match_pattern, version)
+        if self._set_versions(match_obj):
+            return
+
+        # handle engineering builds "4.2(0.175a)"
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]{0,2})))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\."
+                                   r"(?P<build>(([0-9])|([1-9][0-9]{0,})))"
+                                   r"(?P<patch>[a-z])\)$")
+        match_obj = re.match(match_pattern, version)
+        if self._set_versions(match_obj):
+            return
+
+        # handle spin builds "4.2(1.2021052301)"
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]{0,1})))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))\."
+                                   r"(?P<spin>\d{0,4}\d{0,2}\d{0,2}\d{0,2})\)$")
+        match_obj = re.match(match_pattern, version)
+        if self._set_versions(match_obj):
+            return
+
+        # handle patch spin builds "4.2(1a.2021052301)"
+        match_pattern = re.compile(r"^(?P<major>[1-9][0-9]{0,2})\."
+                                   r"(?P<minor>(([0-9])|([1-9][0-9]{0,1})))\("
+                                   r"(?P<mr>(([0-9])|([1-9][0-9]{0,2})))"
+                                   r"(?P<patch>[a-z])\."
+                                   r"(?P<spin>\d{0,4}\d{0,2}\d{0,2}\d{0,2})\)$")
+        match_obj = re.match(match_pattern, version)
+        if self._set_versions(match_obj):
+            return
+
+    def _set_versions(self, match_obj):
+        if not match_obj:
+            return False
+
+        match_dict = match_obj.groupdict()
+        self.__major = match_dict.get("major")
+        self.__minor = match_dict.get("minor")
+        self.__mr = match_dict.get("mr")
+        self.__patch = match_dict.get("patch")
+        self.__spin = match_dict.get("spin")
+        self.__build = match_dict.get("build")
+
+        # for spin builds 4.0(1S52), the patch version will be None
+        # In this scenario assume the version to be highest patch z
+        if self.__patch is None:
+            self.__patch = 'z'
+        elif self.__patch.isdigit() and self.__mr.isdigit():
+            log.debug("Interim version encountered: %s. MR version has been bumped up." % self.version)
+            self.__mr = str(int(self.__mr) + 1)
+            self.__patch = 'a'
+        elif self.__patch.isalpha() and self.__spin:
+            log.debug("Interim version encountered: %s. patch version has been bumped up." % self.version)
+            self.__patch = str(chr(ord(self.__patch) + 1))
+
+        return True
+
     @property
     def major(self):
         """Getter Method of UcscVersion Class"""
@@ -97,23 +175,48 @@ class UcscVersion(object):
         """Getter Method of UcscVersion Class"""
         return self.__patch
 
+    @property
+    def spin(self):
+        """Getter Method of UcscVersion Class"""
+        return self.__spin
+
+    @property
+    def build(self):
+        """Getter Method of UcscVersion Class"""
+        return self.__build
+
     @property
     def version(self):
         """Getter Method of UcscVersion Class"""
         return self.__version
 
+    def _compare(self, version1, version2):
+        if version1 == version2:
+            return 0
+        if not version1:
+            return -1
+        if not version2:
+            return 1
+
+        func = (ord, int)[version1.isdigit() and version2.isdigit()]
+        return func(version1) - func(version2)
+
     def compare_to(self, version):
         """Method to compare UcscVersion."""
         if version is None or not isinstance(version, UcscVersion):
             return 1
 
-        if self.__major != version.major:
-            return ord(self.__major) - ord(version.major)
-        if self.__minor != version.minor:
-            return ord(self.__minor) - ord(version.major)
-        if self.__mr != version.mr:
-            return ord(self.__mr) - ord(version.mr)
-        return ord(self.__patch) - ord(version.patch)
+        ret = 0
+        versions = [(self.__major, version.major),
+                    (self.__minor, version.minor),
+                    (self.__mr, version.mr),
+                    (self.__build, version.build),
+                    (self.__patch, version.patch)]
+        for item in versions:
+            ret = self._compare(item[0], item[1])
+            if ret:
+                return ret
+        return ret
 
     def __gt__(self, version):
         return self.compare_to(version) > 0
@@ -127,6 +230,12 @@ class UcscVersion(object):
     def __le__(self, version):
         return self.compare_to(version) <= 0
 
+    def __eq__(self, version):
+        return self.compare_to(version) == 0
+
+    def __ne__(self, version):
+        return self.compare_to(version) != 0
+
     def __str__(self):
         return self.__version
 
